#ifndef _ELDBUS_MODEL_CONNECTION_EO_H_
#define _ELDBUS_MODEL_CONNECTION_EO_H_

#ifndef _ELDBUS_MODEL_CONNECTION_EO_CLASS_TYPE
#define _ELDBUS_MODEL_CONNECTION_EO_CLASS_TYPE

typedef Eo Eldbus_Model_Connection;

#endif

#ifndef _ELDBUS_MODEL_CONNECTION_EO_TYPES
#define _ELDBUS_MODEL_CONNECTION_EO_TYPES


#endif
#define ELDBUS_MODEL_CONNECTION_CLASS eldbus_model_connection_class_get()

EAPI const Eo_Class *eldbus_model_connection_class_get(void) EINA_CONST;

EOAPI void eldbus_model_connection_type_set(int value);

EOAPI int eldbus_model_connection_type_get(void);

EOAPI void eldbus_model_connection_address_set(const char *value);

EOAPI const char *eldbus_model_connection_address_get(void);

EOAPI void eldbus_model_connection_private_set(Eina_Bool value);

EOAPI Eina_Bool eldbus_model_connection_private_get(void);

/**
 * @brief Custom Eldbus_Model_Connection constructor.
 *
 * @param[in] address Remote address of dbus
 * @param[in] private_ Non shared dbus connection
 *
 * @since 1.16
 *
 * @ingroup Eldbus_Model_Connection
 */
EOAPI void eldbus_model_connection_constructor(int type, const char *address, Eina_Bool private_);


#endif
