/// @cond EO_CXX_EO_IMPL

inline ::eldbus::model_connection::_c_constructor eldbus::model_connection::constructor(int type_, ::efl::eina::string_view address_, bool private__)
{
   return _c_constructor(type_, address_, private__);
}

inline int eldbus::model_connection::type_get() const
{
   int _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::eldbus_model_connection_type_get());
   return _tmp_ret;
}

inline void eldbus::model_connection::type_set(int value_) const
{
   eo_do(_concrete_eo_ptr(), ::eldbus_model_connection_type_set(value_));
}

inline ::efl::eina::string_view eldbus::model_connection::address_get() const
{
   const char * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::eldbus_model_connection_address_get());
   return ::efl::eolian::to_cxx<::efl::eina::string_view>(_tmp_ret, std::tuple<std::false_type>());
}

inline void eldbus::model_connection::address_set(::efl::eina::string_view value_) const
{
   eo_do(_concrete_eo_ptr(), ::eldbus_model_connection_address_set(::efl::eolian::to_c(value_)));
}

inline bool eldbus::model_connection::private_get() const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::eldbus_model_connection_private_get());
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}

inline void eldbus::model_connection::private_set(bool value_) const
{
   eo_do(_concrete_eo_ptr(), ::eldbus_model_connection_private_set(::efl::eolian::to_c(value_)));
}

inline int eo_cxx::eldbus::model_connection::type_get() const
{
   int _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::eldbus_model_connection_type_get());
   return _tmp_ret;
}

inline void eo_cxx::eldbus::model_connection::type_set(int value_) const
{
   eo_do(_concrete_eo_ptr(), ::eldbus_model_connection_type_set(value_));
}

inline ::efl::eina::string_view eo_cxx::eldbus::model_connection::address_get() const
{
   const char * _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::eldbus_model_connection_address_get());
   return ::efl::eolian::to_cxx<::efl::eina::string_view>(_tmp_ret, std::tuple<std::false_type>());
}

inline void eo_cxx::eldbus::model_connection::address_set(::efl::eina::string_view value_) const
{
   eo_do(_concrete_eo_ptr(), ::eldbus_model_connection_address_set(::efl::eolian::to_c(value_)));
}

inline bool eo_cxx::eldbus::model_connection::private_get() const
{
   Eina_Bool _tmp_ret;
   eo_do(_concrete_eo_ptr(), _tmp_ret = ::eldbus_model_connection_private_get());
   return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
}

inline void eo_cxx::eldbus::model_connection::private_set(bool value_) const
{
   eo_do(_concrete_eo_ptr(), ::eldbus_model_connection_private_set(::efl::eolian::to_c(value_)));
}

inline ::eo_cxx::eldbus::model_connection::operator ::eldbus::model_connection() const
{
   return *static_cast<::eldbus::model_connection const*>(static_cast<void const*>(this));
}

inline ::eo_cxx::eldbus::model_connection::operator ::eldbus::model_connection&()
{
   return *static_cast<::eldbus::model_connection*>(static_cast<void*>(this));
}

inline ::eo_cxx::eldbus::model_connection::operator ::eldbus::model_connection const&() const
{
   return *static_cast<::eldbus::model_connection const*>(static_cast<void const*>(this));
}

template <typename T>
int eldbus_model_connection_type_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   try
      {
         return static_cast<T*>(self->this_)->type_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
         int _tmp_ret{};
         return _tmp_ret;
      }
}

template <typename T>
void eldbus_model_connection_type_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, int value_)
{
   try
      {
         static_cast<T*>(self->this_)->type_set(value_);
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
::efl::eina::string_view eldbus_model_connection_address_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   try
      {
         return static_cast<T*>(self->this_)->address_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
         const char * _tmp_ret{};
         return ::efl::eolian::to_cxx<::efl::eina::string_view>(_tmp_ret, std::tuple<std::false_type>());
      }
}

template <typename T>
void eldbus_model_connection_address_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, const char * value_)
{
   try
      {
         static_cast<T*>(self->this_)->address_set(::efl::eolian::to_cxx<::efl::eina::string_view>(value_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

template <typename T>
bool eldbus_model_connection_private_get_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self)
{
   try
      {
         return static_cast<T*>(self->this_)->private_get();
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
         Eina_Bool _tmp_ret{};
         return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }
}

template <typename T>
void eldbus_model_connection_private_set_wrapper(Eo* objid EINA_UNUSED, ::efl::eo::detail::Inherit_Private_Data* self, Eina_Bool value_)
{
   try
      {
         static_cast<T*>(self->this_)->private_set(::efl::eolian::to_cxx<bool>(value_, std::tuple<std::false_type>()));
      }
   catch (...)
      {
         eina_error_set( ::efl::eina::unknown_error() );
      }
}

namespace efl { namespace eo { namespace detail {

template<>
struct operations< ::eldbus::model_connection >
{
   template <typename T>
   struct type
         : virtual operations< ::eo::base >::template type<T>
         , virtual operations< ::efl::model::base >::template type<T>
   {
      virtual int type_get()
      {
         int _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::eldbus_model_connection_type_get());
            return _tmp_ret;
      }

      virtual void type_set(int value_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::eldbus_model_connection_type_set(value_));
      }

      virtual ::efl::eina::string_view address_get()
      {
         const char * _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::eldbus_model_connection_address_get());
            return ::efl::eolian::to_cxx<::efl::eina::string_view>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void address_set(::efl::eina::string_view value_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::eldbus_model_connection_address_set(::efl::eolian::to_c(value_)));
      }

      virtual bool private_get()
      {
         Eina_Bool _tmp_ret = {};

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               _tmp_ret = ::eldbus_model_connection_private_get());
            return ::efl::eolian::to_cxx<bool>(_tmp_ret, std::tuple<std::false_type>());
      }

      virtual void private_set(bool value_)
      {

         eo_do_super(dynamic_cast<T*>(this)->_eo_ptr(),
               dynamic_cast<T*>(this)->_eo_class(),
               ::eldbus_model_connection_private_set(::efl::eolian::to_c(value_)));
      }

   };
};


template<>
struct operation_description_class_size< ::eldbus::model_connection >
{
   static constexpr int value = 
#if defined(MODEL_CONNECTION_PROTECTED) && defined(MODEL_CONNECTION_BETA)
      6
#elif defined(MODEL_CONNECTION_PROTECTED)
      6
#elif defined(MODEL_CONNECTION_BETA)
      6
#else
      6
#endif
      + operation_description_class_size<::eo::base >::value      + operation_description_class_size<::efl::model::base >::value;
};

template <typename T>
int initialize_operation_description(::efl::eo::detail::tag<::eldbus::model_connection>
                                 , Eo_Op_Description* ops)
{
   int i = 0;
   (void)i;
   (void)ops;
   ops[i].func = reinterpret_cast<void*>(& ::eldbus_model_connection_type_get_wrapper<T>);
   ops[i].api_func = reinterpret_cast<void*>(& ::eldbus_model_connection_type_get);
   ops[i].op_type = EO_OP_TYPE_REGULAR;
   ++i;

   ops[i].func = reinterpret_cast<void*>(& ::eldbus_model_connection_type_set_wrapper<T>);
   ops[i].api_func = reinterpret_cast<void*>(& ::eldbus_model_connection_type_set);
   ops[i].op_type = EO_OP_TYPE_REGULAR;
   ++i;

   ops[i].func = reinterpret_cast<void*>(& ::eldbus_model_connection_address_get_wrapper<T>);
   ops[i].api_func = reinterpret_cast<void*>(& ::eldbus_model_connection_address_get);
   ops[i].op_type = EO_OP_TYPE_REGULAR;
   ++i;

   ops[i].func = reinterpret_cast<void*>(& ::eldbus_model_connection_address_set_wrapper<T>);
   ops[i].api_func = reinterpret_cast<void*>(& ::eldbus_model_connection_address_set);
   ops[i].op_type = EO_OP_TYPE_REGULAR;
   ++i;

   ops[i].func = reinterpret_cast<void*>(& ::eldbus_model_connection_private_get_wrapper<T>);
   ops[i].api_func = reinterpret_cast<void*>(& ::eldbus_model_connection_private_get);
   ops[i].op_type = EO_OP_TYPE_REGULAR;
   ++i;

   ops[i].func = reinterpret_cast<void*>(& ::eldbus_model_connection_private_set_wrapper<T>);
   ops[i].api_func = reinterpret_cast<void*>(& ::eldbus_model_connection_private_set);
   ops[i].op_type = EO_OP_TYPE_REGULAR;
   ++i;

   initialize_operation_description<T>(::efl::eo::detail::tag<::eo::base>(), &ops[operation_description_class_size< ::eldbus::model_connection >::value]);
   initialize_operation_description<T>(::efl::eo::detail::tag<::efl::model::base>(), &ops[operation_description_class_size< ::eldbus::model_connection >::value + operation_description_class_size<::eo::base>::value]);
   return 0;
}
inline Eo_Class const* get_eo_class(tag<::eldbus::model_connection>)
{
   return (ELDBUS_MODEL_CONNECTION_CLASS);
}

} } }

/// @endcond

